#ifndef NT2_CORE_INCLUDE_FUNCTIONS_DEPTH_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_DEPTH_HPP_INCLUDED

#include <nt2/core/functions/depth.hpp>
#include <nt2/core/functions/expr/depth.hpp>
#include <nt2/core/functions/scalar/depth.hpp>

#endif
